@@ -72,4 +72,4 @@ class YleAreenaController(BaseMediaPlayer):
 
         play_media_done_event.wait(10)
         if not play_media_done_event.is_set():
-            raise PyChromecastError()
+            raise PyChromecastError()  # pylint: disable=broad-exception-raised
