@@ -56,6 +56,8 @@ CONNECTION_STATUS_FAILED = "FAILED"
 CONNECTION_STATUS_FAILED_RESOLVE = "FAILED_RESOLVE"
 # The socket connection was lost and needs to be retried
 CONNECTION_STATUS_LOST = "LOST"
+# Check for select poll method
+SELECT_HAS_POLL = hasattr(select, "poll")
 
 HB_PING_TIME = 10
 HB_PONG_TIME = 10
@@ -206,7 +208,7 @@ class SocketClient(threading.Thread):
         self.destination_id = None
         self.session_id = None
         self._request_id = 0
-        # dict mapping requestId on threading.Event objects
+        # dict mapping requestId to callback functions
         self._request_callbacks = {}
         self._open_channels = []
 
@@ -239,10 +241,6 @@ class SocketClient(threading.Thread):
             self.socket.close()
             self.socket = None
 
-        # Make sure nobody is blocking.
-        for callback in self._request_callbacks.values():
-            callback["event"].set()
-
         self.app_namespaces = []
         self.destination_id = None
         self.session_id = None
@@ -281,6 +279,10 @@ class SocketClient(threading.Thread):
                 if now < retry["next_retry"]:
                     continue
                 try:
+                    if self.socket is not None:
+                        self.socket.close()
+                        self.socket = None
+
                     self.socket = new_socket()
                     self.socket.settimeout(self.timeout)
                     self._report_connection_status(
@@ -555,7 +557,7 @@ class SocketClient(threading.Thread):
         Use run_once() in your own main loop after you
         receive something on the socket (get_socket()).
         """
-        # pylint: disable=too-many-branches, too-many-return-statements
+        # pylint: disable=too-many-branches, too-many-statements, too-many-return-statements
 
         try:
             if not self._check_connection():
@@ -565,15 +567,19 @@ class SocketClient(threading.Thread):
 
         # poll the socket, as well as the socketpair to allow us to be interrupted
         rlist = [self.socket, self.socketpair[0]]
-        # Map file descriptors to socket objects because select.select does not support fd > 1024
-        # https://stackoverflow.com/questions/14250751/how-to-increase-filedescriptors-range-in-python-select
-        fd_to_socket = {rlist_item.fileno(): rlist_item for rlist_item in rlist}
         try:
-            poll_obj = select.poll()
-            for poll_fd in rlist:
-                poll_obj.register(poll_fd, select.POLLIN)
-            poll_result = poll_obj.poll(timeout * 1000)  # timeout in milliseconds
-            can_read = [fd_to_socket[fd] for fd, _status in poll_result]
+            if SELECT_HAS_POLL is True:
+                # Map file descriptors to socket objects because select.select does not support fd > 1024
+                # https://stackoverflow.com/questions/14250751/how-to-increase-filedescriptors-range-in-python-select
+                fd_to_socket = {rlist_item.fileno(): rlist_item for rlist_item in rlist}
+
+                poll_obj = select.poll()
+                for poll_fd in rlist:
+                    poll_obj.register(poll_fd, select.POLLIN)
+                poll_result = poll_obj.poll(timeout * 1000)  # timeout in milliseconds
+                can_read = [fd_to_socket[fd] for fd, _status in poll_result]
+            else:
+                can_read, _, _ = select.select(rlist, [], [], timeout)
         except (ValueError, OSError) as exc:
             self.logger.error(
                 "[%s(%s):%s] Error in select call: %s",
@@ -638,15 +644,8 @@ class SocketClient(threading.Thread):
         # See if any handlers will accept this message
         self._route_message(message, data)
 
-        if REQUEST_ID in data:
-            callback = self._request_callbacks.pop(data[REQUEST_ID], None)
-            if callback is not None:
-                event = callback["event"]
-                callback["response"] = data
-                function = callback["function"]
-                event.set()
-                if function:
-                    function(data)
+        if REQUEST_ID in data and data[REQUEST_ID] in self._request_callbacks:
+            self._request_callbacks.pop(data[REQUEST_ID], None)(data)
 
         return 0
 
@@ -704,7 +703,6 @@ class SocketClient(threading.Thread):
         """Route message to any handlers on the message namespace"""
         # route message to handlers
         if message.namespace in self._handlers:
-
             # debug messages
             if message.namespace != NS_HEARTBEAT:
                 self.logger.debug(
@@ -913,11 +911,7 @@ class SocketClient(threading.Thread):
             try:
                 if callback_function:
                     if not no_add_request_id:
-                        self._request_callbacks[request_id] = {
-                            "event": threading.Event(),
-                            "response": None,
-                            "function": callback_function,
-                        }
+                        self._request_callbacks[request_id] = callback_function
                     else:
                         callback_function(None)
                 self.socket.sendall(be_size + msg.SerializeToString())
